<div id="content">

<div class="default">
<p>
<? echo $this->get_allinone_intro(); ?>
</p>
</div>

<?
function display_all_in_one($tree,&$page) {
  $content=new UWC_Content($page->data,$tree->get_path(),$page->context->get_lang(),$page->auth);

  $title=$content->get_title();
  if ($title || $content->get_text()) {
    if ($title) {
      $title=uwc_format_text_to_html($title);
    } else {
      $title=$page->translate("no_title");
    }

    echo "<div class=\"status".$content->get_status()."\">\n";
    echo "<h1><a href=\"".$page->make_url($content->get_path())."\">".$title."</a></h1>\n";
    
    $orig_path=$page->get_path();
    $page->set_allinone_path($content->get_path());
    echo uwc_format_phpwiki_to_html($content->get_text());
    $page->set_allinone_path($orig_path);
    
    echo "</div>\n\n";
  }

  $subtrees=& $tree->get_subtrees();
  if (count($subtrees)) {
    echo "\n\n";
    foreach ($subtrees as $subtree) {
      display_all_in_one($subtree,$page);
    }
  }									     
}

display_all_in_one($this->get_tree(),$this);
?>

</div>
